@@ -19,12 +19,12 @@ use aliased 'Devel::Declare::Context::Simple', 'ContextSimple';
 
 use namespace::autoclean;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 has package => (
-    is           => 'ro',
-    isa          => Str,
-    lazy_require => 1,
+    is            => 'ro',
+    isa           => Str,
+    lazy_required => 1,
 );
 
 has context => (
